﻿#region Copyright
/// <summary>The ScummVM WPF UI project</summary>
/// <copyright>(c) 2016 MojoTouch</copyright>
/// <author>Ilya Rovensky</author>
#endregion

using System;
using System.Collections;
using System.Collections.Generic;
using System.Threading;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;

namespace WpfInterface
{
    public enum MenuAction
    {
        Splash = 0,
        NewGame = 1,
        Continue = 2,
        Save = 3,
        Load = 4,
        Quit = 5,
        Settings = 6,
        Main = 7,
        OpenHouse = 8,

        SettingsVoice = 9,
        SettingsMusic = 10,
        SettingsLanguage = 11,
        SettingsGraphics = 12,
        SettingsControls = 13,
        SettingsAbout = 14,
        SettingsBack = 15,

        Tutorial = 16,
        Progress = 17,

        List = 18,
        ListSlot1 = 19,
        ListSlot2 = 20,
        ListSlot3 = 21,
        ListSlot4 = 22,
        ListSlot5 = 23,
        ListSlot6 = 24,
        ListSlot7 = 25,
        ListSlot8 = 26,
        SelectNegative = 27,
        SelectPositive = 28,

        Input = 29,

        Alert = 30,
        AlertButton1 = 32,
        AlertButton2 = 32,
        AlertButton3 = 33,

        SettingsRateUs = 34,

        DeveloperLogo1 = 41,
        DeveloperLogo2 = 42,

        Extras = 43,
        EnableOpenHouse = 44
    }

    public enum LocString
    {
        app_desc,
        quit,
        no_sdcard,
        restart_needed,
        music_mode_no_music,
        music_mode_original,
        music_mode_original_recording,
        music_mode_original_mt32,
		music_mode_original_general_midi,
        music_mode_original_eas,
        music_mode_enhanced,
        voice_mode_voice_subtitles,
        voice_mode_voice_only,
        voice_mode_subtitles_only,
        scaling_option_lq_shader,
        scaling_option_shader,
        scaling_option_shader_native_res,
        scaling_option_software,
        scaling_option_none,
        control_mode_touch,
        control_mode_classic,
        control_mode_classic_desktop_new_cursors,
        control_mode_enhanced_desktop,
        control_mode_enhanced_desktop_classic_bar,
        control_mode_touch_desc,
        control_mode_classic_desc,
        control_mode_touch_classic_bar,
        music_mode,
        voice_mode,
        language,
        scaling_option,
        unable_to_create_game_files_connect_external_storage,
        unable_to_create_game_files_error_dialog,
        ok,
        yes,
        no,
        text_validation_failed,
        text_button_pause,
        text_button_resume,
        text_button_cancel,
        text_button_cancel_verify,
        failure_message_unknown,
        failure_message_cancelled,
        failure_message_connection,
        failure_message_license,
        failure_message_sdcard,
        preparing_game_files,
        cancel,
        exit_confirmation_message,
        expansion_downloader_upper_text,
        expansion_downloader_upper_text_validating,
        choose_save_slot,
        choose_load_slot,
        enter_save_name,
        save_success,
        save_failure,
        load_success,
        load_failure,
        load_failure_no_saves,
        save_game_reminder,
        empty_slot,
        files_fraction,
        save_progress_dialog,
        load_progress_dialog,
        no_saved_games,
        continue_,
        save_game,
        load_game,
        new_game,
        settings,
        tutorial,
        game_tutorial,
        exit_button,
        controls,
        about,
        back,
        menu_subtitle,
        shader_test_message,
        rate_message,
        rate,
        rate_later,
        rate_cancel,
        tutorial_prompt,
        graphic_setting_message,
        mt32_warning_message,
        prepare_game_files_no_space_message,
        storage_unavailable,
        new_game_confirmation,
        rate_us,
        store_page,
        share_chooser,
        share_message,
        open_house_prompt,
        achievement_popup_title,
        enable_achievement_popup_checkbox,
        facebook_share_achievement_btn,
        facebook_login_dialog_title,
        facebook_share_achievement_dialog_title,
        facebook_share_achievement_input_hint,
        facebook_share_achievement_success_toast,
        facebook_share_achievement_failure_toast,
        skip_english_puzzle_popup,
        microscope_puzzle_popup,
        like_view_error,
        error_opening_extra_file,
        error_opening_epub_file,
        achievements,
        extras,
        subtitle_speed,
        load_change_language_popup,
        bishops_puzzle_popup,
        no_amazon_appstore,
        english,
        english_sub,
        german,
        german_sub,
        hebrew,
        hebrew_sub,
        spanish,
        spanish_sub,
        portuguese,
        portuguese_sub,
        french,
        french_sub,
        russian,
        russian_sub,
        italian,
        italian_sub,
        czech,
        czech_sub,
        polish,
        polish_sub,
        swedish,
        swedish_sub,
        music_volume,
        speech_volume,
        sfx_volume
    };

    public enum GameType { Unknown =-1, Simon1 = 0, Simon2 = 1, Fotaq = 2, Indy_Foa = 3, T7G = 4, IHNM = 5, TONYT = 6, ITE = 7 }

    public class MenuState
    {
        public bool IsContinueEnabled { get; }
        public bool IsSaveEnabled { get; }
        public bool IsLoadEnabled { get; }
        public bool HasTutorial { get; }
        public bool IsOpenHouseEnabled { get; }
        public bool HasExtras { get; }
        public bool HasCrossPromotionButton { get; }
       
        public MenuState(int bits, int gameToPromote = -1)
        {
            BitArray bitArray = new BitArray(new []{ bits });

            IsContinueEnabled = bitArray[0];
            IsSaveEnabled = bitArray[1];
            IsLoadEnabled = bitArray[2];
            HasTutorial = bitArray[3];
            IsOpenHouseEnabled = bitArray[4];
            HasExtras = bitArray[5];
            HasCrossPromotionButton = bitArray[6];
        }
    }

    public class Menu : UserControl //Page
    {
        public MenuState State { get; set; }

        private MenuAction _result;
        ManualResetEvent _waitEvent = new ManualResetEvent(false);

#if TARGET_T7G
        string stringResult = String.Empty;
        public void HandleHandledKeyDown(object sender, RoutedEventArgs e)
        {
            KeyEventArgs ke = e as KeyEventArgs;
            if (ke.Key == Key.Space)
            {
                ke.Handled = false;
            }

            if (stringResult.Length > 16 || !(ke.Key >= Key.A && ke.Key <= Key.Z))
            {
                stringResult = String.Empty;
            }
            else
            {
                stringResult += ke.Key.ToString();
            }
            //Log(string.Format("stringResult = {0}.", stringResult));
            //Log(string.Format("stringResult Length = {0}.", stringResult.Length));

            //if (stringResult.Equals("ZAP") && !State.IsOpenHouseEnabled) //DEBUG
            if (stringResult.Equals("ZAPHODBEEBLEBROX") && !State.IsOpenHouseEnabled)
            {
                //Log(string.Format("stringResult Length 3 = {0}.", stringResult));
                Log("Menu: T7G Easter egg unlocked");
                Log("Playing WAV: groovie");
                new System.Media.SoundPlayer($"{Assets.Path}/wav/groovie.wav").Play();
                Result = (MenuAction)44;
            }
        }
#endif     

        /// <summary>
        /// The result of the menu showing. Getting the result will wait for a user input. Setting it will trigger return.
        /// </summary>
        public MenuAction Result
        {
            get
            {
                if (_waitEvent != null)
                {
                    UserInterface.Log("Waiting for result.");
#if TARGET_T7G
                    this.AddHandler(Window.KeyDownEvent, new RoutedEventHandler(HandleHandledKeyDown), true);
#endif
                    _waitEvent.WaitOne();
                    _waitEvent.Dispose();
                    _waitEvent = null;
                }
                return _result;
            }
            set
            {
                _result = value;
                if (_waitEvent != null)
                {
                    UserInterface.Log("The result is set.");
                    _waitEvent.Set();
                }
            }
        }

        public void ShowAgain()
        {
            if (_waitEvent == null)
                _waitEvent = new ManualResetEvent(false);
        }

        protected void SetResultFromSenderTag(FrameworkElement sender)
        {
            Result = (MenuAction)int.Parse((sender).Tag.ToString());
        }

        private List<string> _strings;
        public List<string> Strings
        {
            get
            {
                /*
                System.Globalization.CultureInfo ci = new System.Globalization.CultureInfo("en-US");
                Thread.CurrentThread.CurrentCulture = ci;
                Thread.CurrentThread.CurrentUICulture = ci;
                */
                return _strings;
            }
            set
            {
                /*
                System.Globalization.CultureInfo ci = new System.Globalization.CultureInfo("en-US");
                Thread.CurrentThread.CurrentCulture = ci;
                Thread.CurrentThread.CurrentUICulture = ci;
                */
                /*
                for (int i = 0; i < value.Count; i++)
                { // Change Culture
                    value[i].ToString(System.Globalization.CultureInfo.CreateSpecificCulture("en-US"));
                }
                */
                /*
                for (int i = 0; i < value.Count; i++)
                { // Change Encoding
                    string encodeString = value[i];
                    // Create two different encodings.
                    System.Text.Encoding new_encode = System.Text.Encoding.Default;
                    System.Text.Encoding encode = System.Text.Encoding.UTF8;
                    //Encoding encode = Encoding.GetEncoding(38598);

                    // Convert the string into a byte array.
                    byte[] encodeBytes = encode.GetBytes(encodeString);

                    // Perform the conversion from one encoding to the other.
                    byte[] new_encodeBytes = System.Text.Encoding.Convert(encode, new_encode, encodeBytes);

                    // Convert the new byte[] into a char[] and then into a string.
                    char[] new_encodeChars = new char[new_encode.GetCharCount(new_encodeBytes, 0, new_encodeBytes.Length)];
                    new_encode.GetChars(new_encodeBytes, 0, new_encodeBytes.Length, new_encodeChars, 0);
                    string new_encodeString = new string(new_encodeChars);
                    value[i] = new_encodeString;
                }
                */
                _strings = value;
                StringsChanged();
            }
        }

        protected virtual void StringsChanged()
        {

        }

        public Menu(int menuState, bool emptyBackground = false) : this(emptyBackground)
        {
            State = new MenuState(menuState);
            if (!emptyBackground)
            {
                if (!State.IsOpenHouseEnabled)
                {
                    Background = new ImageBrush(new BitmapImage(new Uri(BaseUriHelper.GetBaseUri(this), $"{Assets.Path}/images/bg.png")));
                }
                else
                {
                    Background = new ImageBrush(new BitmapImage(new Uri(BaseUriHelper.GetBaseUri(this), $"{Assets.Path}/images/bg_openhouse.png")));
                }
            }
        }

        public Menu(bool emptyBackground = false)
        {
            if (!emptyBackground)
            {
                Background = new ImageBrush(new BitmapImage(new Uri(BaseUriHelper.GetBaseUri(this), $"{Assets.Path}/images/bg.png")));
            }
        }

        /// <summary>
        /// Logs a message to the console
        /// </summary>
        /// <param name="message">A message to display, an exception or any other object</param>
        public static void Log(object message)
        {
#if DEBUG
            Console.WriteLine(string.Format("************ {0: yyyy/MM/dd hh.mm.ss.fff}: [WPF UI] {1}", DateTime.Now, message));
#else
            // causes hanging up in the middle of the game
            //File.AppendAllText("log.txt", string.Format("{0: yyyy/MM/dd hh.mm.ss.fff}: {1}\n", DateTime.Now, message));
#endif
        }
    }
}
